pub enum MintQuoteResponse {
Bolt11(MintQuoteBolt11Response<QuoteId>),
Bolt12(MintQuoteBolt12Response<QuoteId>),
Custom {
method: String,
response: MintQuoteCustomResponse<QuoteId>,
},
}Expand description
Response for a mint quote request
This enum represents the different types of payment responses that can be returned when creating a mint quote.
Variants
Bolt11(MintQuoteBolt11Response<QuoteId>)
Lightning Network BOLT11 invoice response
Bolt12(MintQuoteBolt12Response<QuoteId>)
Lightning Network BOLT12 offer response
Custom
Custom payment method response
Fields

response: MintQuoteCustomResponse<QuoteId>Generic response data