pub struct NostrWaitInfo {
pub keys: Keys,
pub relays: Vec<String>,
pub pubkey: PublicKey,
}Expand description
Extra information needed to wait for an incoming Nostr payment
Returned by create_request when the transport is nostr. Pass this to
wait_for_nostr_payment to connect, subscribe, and receive the incoming
payment on the specified relays.
Fields
keys: KeysEphemeral keys used to connect to relays and unwrap the gift-wrapped event
relays: Vec<String>Nostr relays to read from while waiting for the payment
pubkey: PublicKeyThe recipient public key to subscribe to for incoming events