AuthWallet

Struct AuthWallet 

pub struct AuthWallet {
    pub mint_url: MintUrl,
    pub localstore: Arc<dyn WalletDatabase<Error> + Send + Sync>,
    pub metadata_cache: Arc<MintMetadataCache>,
    pub protected_endpoints: Arc<RwLock<HashMap<ProtectedEndpoint, AuthRequired>>>,
    /* private fields */
}
CDK Auth Wallet

A AuthWallet is for auth operations with a single mint.

Fields

mint_url: MintUrl

Mint Url

localstore: Arc<dyn WalletDatabase<Error> + Send + Sync>

Storage backend

metadata_cache: Arc<MintMetadataCache>

Mint metadata cache (lock-free cached access to keys, keysets, and mint info)

protected_endpoints: Arc<RwLock<HashMap<ProtectedEndpoint, AuthRequired>>>

Protected methods

Implementations

Source

impl AuthWallet

pub fn new( mint_url: MintUrl, cat: Option<AuthToken>, localstore: Arc<dyn WalletDatabase<Error> + Send + Sync>, metadata_cache: Arc<MintMetadataCache>, protected_endpoints: HashMap<ProtectedEndpoint, AuthRequired>, oidc_client: Option<OidcClient>, ) -> Self

Create a new AuthWallet instance

pub async fn get_auth_token(&self) -> Result<AuthToken, Error>

Get the current auth token

pub async fn verify_cat(&self, token: AuthToken) -> Result<(), Error>

Set a new auth token

pub async fn set_auth_token(&self, token: AuthToken) -> Result<(), Error>

Set a new auth token

pub async fn get_refresh_token(&self) -> Option<String>

Get the current refresh token if one exists

pub async fn set_refresh_token(&self, token: Option<String>)

Set a new refresh token

pub async fn get_oidc_client(&self) -> Option<OidcClient>

Get the OIDC client if one exists

pub async fn set_oidc_client(&self, client: Option<OidcClient>)

Set a new OIDC client

pub async fn refresh_access_token(&self) -> Result<(), Error>

Refresh the access token using the stored refresh token

pub async fn get_mint_info(&self) -> Result<Option<MintInfo>, Error>

Query mint for current mint information

pub async fn load_keyset_keys(&self, keyset_id: Id) -> Result<Keys, Error>

Fetch keys for mint keyset

Returns keys from metadata cache if available, fetches from mint if not.

pub async fn load_mint_keysets(&self) -> Result<Vec<KeySetInfo>, Error>

Get blind auth keysets from metadata cache

Checks the metadata cache for auth keysets. If cache is not populated, fetches from the mint server and updates the cache. This is the main method for getting auth keysets in operations that can work offline but will fall back to online if needed.

pub async fn refresh_keysets(&self) -> Result<Vec<KeySetInfo>, Error>

Refresh blind auth keysets by fetching the latest from mint

Fetches the latest blind auth keyset information from the mint server, updating the metadata cache and database. Returns only the keysets with Auth currency unit. Use this when you need the most up-to-date keyset information.

pub async fn fetch_active_keyset(&self) -> Result<KeySetInfo, Error>

Get the first active blind auth keyset - always goes online

This method always goes online to refresh keysets from the mint and then returns the first active keyset found. Use this when you need the most up-to-date keyset information for blind auth operations.

pub async fn get_unspent_auth_proofs(&self) -> Result<Vec<AuthProof>, Error>

Get unspent auth proofs from local database only - offline operation

Returns auth proofs from the local database that are in the Unspent state. This is an offline operation that does not contact the mint.

pub async fn is_protected( &self, method: &ProtectedEndpoint, ) -> Option<AuthRequired>

Check if and what kind of auth is required for a method

pub async fn get_blind_auth_token( &self, ) -> Result<Option<BlindAuthToken>, Error>

Get Auth Token

pub async fn get_auth_for_request( &self, method: &ProtectedEndpoint, ) -> Result<Option<AuthToken>, Error>

Auth for request

pub async fn mint_blind_auth(&self, amount: Amount) -> Result<Proofs, Error>

Mint blind auth

pub async fn total_blind_auth_balance(&self) -> Result<Amount, Error>

Total unspent balance of wallet

Source

impl AuthWallet

pub fn get_metadata_cache_info(&self) -> FreshnessStatus

Get information about metadata cache info