pub enum SwapSagaState {
ProofsReserved,
SwapRequested,
}Expand description
States specific to swap saga (wallet-side)
Variants
ProofsReserved
Input proofs reserved, swap request prepared, ready to execute
SwapRequested
Swap request sent to mint, awaiting signatures for new proofs