pub struct ReceiveOperationData {
pub token: Option<String>,
pub counter_start: Option<u32>,
pub counter_end: Option<u32>,
pub amount: Option<Amount>,
pub blinded_messages: Option<Vec<BlindedMessage>>,
}Expand description
Operation-specific data for Receive operations
Fields
token: Option<String>Token to receive
counter_start: Option<u32>Derivation counter start
counter_end: Option<u32>Derivation counter end
amount: Option<Amount>Amount received
blinded_messages: Option<Vec<BlindedMessage>>Blinded messages for recovery
Stored so that if a crash occurs after the mint accepts the swap, we can use these to query the mint for signatures and reconstruct proofs.