pub struct Transaction {Show 14 fields
pub mint_url: MintUrl,
pub direction: TransactionDirection,
pub amount: Amount,
pub fee: Amount,
pub unit: CurrencyUnit,
pub ys: Vec<PublicKey>,
pub timestamp: u64,
pub memo: Option<String>,
pub metadata: HashMap<String, String>,
pub quote_id: Option<String>,
pub payment_request: Option<String>,
pub payment_proof: Option<String>,
pub payment_method: Option<PaymentMethod>,
pub saga_id: Option<Uuid>,
}Expand description
Wallet Transaction
Fields
mint_url: MintUrlMint Url
direction: TransactionDirectionTransaction direction
amount: AmountAmount
fee: AmountFee
unit: CurrencyUnitCurrency Unit
ys: Vec<PublicKey>Proof Ys
timestamp: u64Unix timestamp
memo: Option<String>Memo
metadata: HashMap<String, String>User-defined metadata
quote_id: Option<String>Quote ID if this is a mint or melt transaction
payment_request: Option<String>Payment request (e.g., BOLT11 invoice, BOLT12 offer)
payment_proof: Option<String>Payment proof (e.g., preimage for Lightning melt transactions)
payment_method: Option<PaymentMethod>Payment method (e.g., Bolt11, Bolt12) for mint/melt transactions
saga_id: Option<Uuid>Saga ID if this transaction was part of a saga
Implementations
Sourceimpl Transaction
impl Transaction
Sourcepub fn id(&self) -> TransactionId
pub fn id(&self) -> TransactionId
Transaction ID
Sourcepub fn matches_conditions(
&self,
mint_url: &Option<MintUrl>,
direction: &Option<TransactionDirection>,
unit: &Option<CurrencyUnit>,
) -> bool
pub fn matches_conditions( &self, mint_url: &Option<MintUrl>, direction: &Option<TransactionDirection>, unit: &Option<CurrencyUnit>, ) -> bool
Check if transaction matches conditions