pub struct TokenData {
pub mint_url: MintUrl,
pub proofs: Proofs,
pub memo: Option<String>,
pub value: Amount,
pub unit: CurrencyUnit,
pub redeem_fee: Option<Amount>,
}Expand description
Data extracted from a token
Contains the mint URL, proofs, and metadata from a parsed token.
Fields
mint_url: MintUrlThe mint URL from the token
proofs: ProofsThe proofs contained in the token
memo: Option<String>The memo from the token, if present
value: AmountValue of token
unit: CurrencyUnitUnit of token
redeem_fee: Option<Amount>Fee to redeem
If the token is for a mint that we do not know, we cannot get the fee. To avoid just erroring and still allow decoding, this is an option. None does not mean there is no fee, it means we do not know the fee.